@@ -144,6 +144,9 @@ def render_ans(pad, ans, width=80, height=25, shift_y=0):
   bgcol = "Bk"
   curcol = "meWhBk"
   lp = 0 # last printed row
+  # init base color
+  if curcol not in clrs:
+    init_cur_clr(fgcol,bgcol,inten)
   # main ansi loop
   for c in ans:
     # from this point there could be SAUCE
@@ -295,7 +298,7 @@ def main():
   # hide the cursor
   curses.curs_set(0)
   # prepare new curses pad
-  pad = curses.newpad(rows, cols*4) # lines, cols
+  pad = curses.newpad(rows, cols*2) # lines, cols
   cli = render_ans(pad,dans,cols,rows,shift_y)
   # screen size variables
   while k != ord("q"):
